[llvm-commits] [llvm-gcc-4.2] r49015 - in /llvm-gcc-4.2/trunk/gcc: config/i386/llvm-i386-target.h llvm-abi.h

Devang Patel dpatel at apple.com
Mon Mar 31 19:02:44 PDT 2008


Author: dpatel
Date: Mon Mar 31 21:02:44 2008
New Revision: 49015

URL: http://llvm.org/viewvc/llvm-project?rev=49015&view=rev
Log:
s/LLVM_SHOULD_RETURN_STRUCT_AS_SCALAR/LLVM_SHOULD_RETURN_SELT_STRUCT_AS_SCALAR/g

Modified:
    llvm-gcc-4.2/trunk/gcc/config/i386/llvm-i386-target.h
    llvm-gcc-4.2/trunk/gcc/llvm-abi.h

Modified: llvm-gcc-4.2/trunk/gcc/config/i386/llvm-i386-target.h
URL: http://llvm.org/viewvc/llvm-project/llvm-gcc-4.2/trunk/gcc/config/i386/llvm-i386-target.h?rev=49015&r1=49014&r2=49015&view=diff

==============================================================================
--- llvm-gcc-4.2/trunk/gcc/config/i386/llvm-i386-target.h (original)
+++ llvm-gcc-4.2/trunk/gcc/config/i386/llvm-i386-target.h Mon Mar 31 21:02:44 2008
@@ -93,8 +93,8 @@
 
 /* Structs containing a single data field plus zero-length fields are
    considered as if they were the type of the data field. */
-#ifndef LLVM_SHOULD_RETURN_STRUCT_AS_SCALAR
-#define LLVM_SHOULD_RETURN_STRUCT_AS_SCALAR(X) \
+#ifndef LLVM_SHOULD_RETURN_SELT_STRUCT_AS_SCALAR
+#define LLVM_SHOULD_RETURN_SELT_STRUCT_AS_SCALAR(X) \
   isSingleElementStructOrArray(X, true, false)
 #endif
 

Modified: llvm-gcc-4.2/trunk/gcc/llvm-abi.h
URL: http://llvm.org/viewvc/llvm-project/llvm-gcc-4.2/trunk/gcc/llvm-abi.h?rev=49015&r1=49014&r2=49015&view=diff

==============================================================================
--- llvm-gcc-4.2/trunk/gcc/llvm-abi.h (original)
+++ llvm-gcc-4.2/trunk/gcc/llvm-abi.h Mon Mar 31 21:02:44 2008
@@ -205,13 +205,14 @@
    !isSingleElementStructOrArray(X, false, true)
 #endif
 
 // LLVM_SHOULD_RETURN_STRUCT_AS_SCALAR - Return a TYPE tree if this struct
 // should be returned using the convention for that scalar TYPE, 0 otherwise.
 // The returned TYPE must be the same size as X for this to work; that is
 // checked elsewhere.  (Structs where this is not the case can be constructed
 // by abusing the __aligned__ attribute.)
-#ifndef LLVM_SHOULD_RETURN_STRUCT_AS_SCALAR
-#define LLVM_SHOULD_RETURN_STRUCT_AS_SCALAR(X) \
+#ifndef LLVM_SHOULD_RETURN_SELT_STRUCT_AS_SCALAR
+#define LLVM_SHOULD_RETURN_SELT_STRUCT_AS_SCALAR(X) \
   isSingleElementStructOrArray(X, false, false)
 #endif
 
@@ -280,7 +281,7 @@
                 && (!TARGET_64BIT || TREE_INT_CST_LOW(TYPE_SIZE_UNIT(type))<=8)
 #endif
                ) {
-      tree SingleElt = LLVM_SHOULD_RETURN_STRUCT_AS_SCALAR(type);
+      tree SingleElt = LLVM_SHOULD_RETURN_SELT_STRUCT_AS_SCALAR(type);
       if (SingleElt && TYPE_SIZE(SingleElt) && 
           TREE_CODE(TYPE_SIZE(SingleElt)) == INTEGER_CST &&
           TREE_INT_CST_LOW(TYPE_SIZE_UNIT(type)) == 
@@ -205,13 +205,14 @@
 #endif
 
-// LLVM_SHOULD_RETURN_STRUCT_AS_SCALAR - Return a TYPE tree if this struct
-// should be returned using the convention for that scalar TYPE, 0 otherwise.
+// LLVM_SHOULD_RETURN_SELT_STRUCT_AS_SCALAR - Return a TYPE tree if this single
+// element struct should be returned using the convention for that scalar TYPE, 
+// 0 otherwise.
 // The returned TYPE must be the same size as X for this to work; that is
 // checked elsewhere.  (Structs where this is not the case can be constructed





More information about the llvm-commits mailing list